from pathlib import Path

from girder.plugin import GirderPlugin, registerPluginStaticContent

from . import rest


class GoogleAnalyticsPlugin(GirderPlugin):
    DISPLAY_NAME = 'Google Analytics'

    def load(self, info):
        info['apiRoot'].google_analytics = rest.GoogleAnalytics()

        registerPluginStaticContent(
            plugin='google_analytics',
            css=['/style.css'],
            js=['/girder-plugin-google-analytics.umd.cjs'],
            staticDir=Path(__file__).parent / 'web_client' / 'dist',
            tree=info['serverRoot'],
        )



from tests import base
from girder.models.setting import Setting

from girder_google_analytics.settings import PluginSettings


def setUpModule():
    base.enabledPlugins.append('google_analytics')
    base.startServer()


def tearDownModule():
    base.stopServer()


class GoogleAnalyticsTest(base.TestCase):

    def testGetAnalytics(self):
        # test without set
        resp = self.request('/google_analytics/id')
        self.assertStatusOk(resp)
        self.assertEqual(resp.json['google_analytics_id'], '')

        # set tracking id
        Setting().set(PluginSettings.TRACKING_ID, 'testing-tracking-id')

        # verify we can get the tracking id without being authenticated.
        resp = self.request('/google_analytics/id')
        self.assertStatusOk(resp)
        self.assertEqual(resp.json['google_analytics_id'], 'testing-tracking-id')
